==> qtjambi-qt3drender-6.2.11-sources.jar: io/qt/qt3d/render/QSetFence.java <==
package io.qt.qt3d.render;


/**
 * <p>FrameGraphNode used to insert a fence in the graphics command stream</p>
 * <p>Java wrapper for Qt's class <a href="https://doc.qt.io/qt/qt3drender-qsetfence.html">Qt3DRender::QSetFence</a></p>
 */
public class QSetFence extends io.qt.qt3d.render.QFrameGraphNode
{
    /**
     * This variable stores the meta-object for the class.
     */
    public static final io.qt.core.QMetaObject staticMetaObject = io.qt.core.QMetaObject.forType(QSetFence.class);
    
    /**
     * <p>Java wrapper for Qt enum Qt3DRender::QSetFence::HandleType</p>
     */
    public enum HandleType implements io.qt.QtEnumerator {
        NoHandle(0),
        OpenGLFenceId(1);

        static {
            QtJambi_LibraryUtilities.initialize();
        }

        private HandleType(int value) {
            this.value = value;
        }

        /**
         * {@inheritDoc}
         */
        public int value() {
            return value;
        }

        /**
         * Returns the corresponding enum entry for the given value.
         * @param value
         * @return enum entry
         */
        public static HandleType resolve(int value) {
            switch (value) {
            case 0: return NoHandle;
            case 1: return OpenGLFenceId;
            default: throw new io.qt.QNoSuchEnumValueException(value);
            }
        }


        private final int value;
    }
    

    /**
     * <p>See <a href="https://doc.qt.io/qt/qt3drender-qsetfence.html#handle-prop">Qt3DRender::QSetFence::handleChanged(QVariant)</a></p>
     */
    @io.qt.QtPropertyNotify(name="handle")
    public final Signal1<java.lang.Object> handleChanged = new Signal1<>();

    /**
     * <p>See <a href="https://doc.qt.io/qt/qt3drender-qsetfence.html#handleType-prop">Qt3DRender::QSetFence::handleTypeChanged(Qt3DRender::QSetFence::HandleType)</a></p>
     */
    @io.qt.QtPropertyNotify(name="handleType")
    public final Signal1<io.qt.qt3d.render.QSetFence.HandleType> handleTypeChanged = new Signal1<>();
    
    /**
     * <p>Overloaded constructor for {@link #QSetFence(io.qt.qt3d.core.QNode)}
     *  with <code>parent = null</code>.</p>
     */
    public QSetFence() {
        this((io.qt.qt3d.core.QNode)null);
    }
    
    @SuppressWarnings({"exports"})
    public QSetFence(io.qt.qt3d.core.QNode parent){
        super((QPrivateConstructor)null);
        initialize_native(this, parent);
    }
    
    private native static void initialize_native(QSetFence instance, io.qt.qt3d.core.QNode parent);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qt3drender-qsetfence.html#handle-prop">Qt3DRender::QSetFence::handle()const</a></p>
     */
    @io.qt.QtPropertyReader(name="handle")
    @io.qt.QtUninvokable
    public final java.lang.Object handle(){
        return handle_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native java.lang.Object handle_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qt3drender-qsetfence.html#handleType-prop">Qt3DRender::QSetFence::handleType()const</a></p>
     */
    @io.qt.QtPropertyReader(name="handleType")
    @io.qt.QtUninvokable
    public final io.qt.qt3d.render.QSetFence.HandleType handleType(){
        return io.qt.qt3d.render.QSetFence.HandleType.resolve(handleType_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this)));
    }
    
    @io.qt.QtUninvokable
    private native int handleType_native_constfct(long __this__nativeId);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     */
    @io.qt.NativeAccess
    protected QSetFence(QPrivateConstructor p) { super(p); } 
    
    /**
     * Constructor for internal use only.
     * It is not allowed to call the declarative constructor from inside Java.
     */
    @io.qt.NativeAccess
    protected QSetFence(QDeclarativeConstructor constructor) {
        super((QPrivateConstructor)null);
        initialize_native(this, constructor);
    } 
    
    @io.qt.QtUninvokable
    private static native void initialize_native(QSetFence instance, QDeclarativeConstructor constructor);
    
}

==> qtjambi-qt3drender-6.3.0-sources.jar: io/qt/qt3d/render/QSetFence.java <==
package io.qt.qt3d.render;


/**
 * <p>FrameGraphNode used to insert a fence in the graphics command stream</p>
 * <p>Java wrapper for Qt class <a href="https://doc.qt.io/qt/qt3drender-qsetfence.html">Qt3DRender::QSetFence</a></p>
 */
public class QSetFence extends io.qt.qt3d.render.QFrameGraphNode
{
    /**
     * This variable stores the meta-object for the class.
     */
    public static final io.qt.core.QMetaObject staticMetaObject = io.qt.core.QMetaObject.forType(QSetFence.class);
    
    /**
     * <p>Java wrapper for Qt enum Qt3DRender::QSetFence::HandleType</p>
     */
    public enum HandleType implements io.qt.QtEnumerator {
        NoHandle(0),
        OpenGLFenceId(1);

        private HandleType(int value) {
            this.value = value;
        }

        /**
         * {@inheritDoc}
         */
        public int value() {
            return value;
        }

        /**
         * Returns the corresponding enum entry for the given value.
         * @param value
         * @return enum entry
         */
        public static HandleType resolve(int value) {
            switch (value) {
            case 0: return NoHandle;
            case 1: return OpenGLFenceId;
            default: throw new io.qt.QNoSuchEnumValueException(value);
            }
        }


        private final int value;
    }
    

    /**
     * <p>See <a href="https://doc.qt.io/qt/qt3drender-qsetfence.html#handle-prop">Qt3DRender::QSetFence::handleChanged(QVariant)</a></p>
     */
    @io.qt.QtPropertyNotify(name="handle")
    public final Signal1<java.lang.Object> handleChanged = new Signal1<>();

    /**
     * <p>See <a href="https://doc.qt.io/qt/qt3drender-qsetfence.html#handleType-prop">Qt3DRender::QSetFence::handleTypeChanged(Qt3DRender::QSetFence::HandleType)</a></p>
     */
    @io.qt.QtPropertyNotify(name="handleType")
    public final Signal1<io.qt.qt3d.render.QSetFence.HandleType> handleTypeChanged = new Signal1<>();
    
    /**
     * <p>Overloaded constructor for {@link #QSetFence(io.qt.qt3d.core.QNode)}
     *  with <code>parent = null</code>.</p>
     */
    public QSetFence() {
        this((io.qt.qt3d.core.QNode)null);
    }
    
    @SuppressWarnings({"exports"})
    public QSetFence(io.qt.qt3d.core.QNode parent){
        super((QPrivateConstructor)null);
        initialize_native(this, parent);
    }
    
    private native static void initialize_native(QSetFence instance, io.qt.qt3d.core.QNode parent);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qt3drender-qsetfence.html#handle-prop">Qt3DRender::QSetFence::handle()const</a></p>
     */
    @io.qt.QtPropertyReader(name="handle")
    @io.qt.QtUninvokable
    public final java.lang.Object handle(){
        return handle_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native java.lang.Object handle_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qt3drender-qsetfence.html#handleType-prop">Qt3DRender::QSetFence::handleType()const</a></p>
     */
    @io.qt.QtPropertyReader(name="handleType")
    @io.qt.QtUninvokable
    public final io.qt.qt3d.render.QSetFence.HandleType handleType(){
        return io.qt.qt3d.render.QSetFence.HandleType.resolve(handleType_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this)));
    }
    
    @io.qt.QtUninvokable
    private native int handleType_native_constfct(long __this__nativeId);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     */
    @io.qt.NativeAccess
    protected QSetFence(QPrivateConstructor p) { super(p); } 
    
    /**
     * Constructor for internal use only.
     * It is not allowed to call the declarative constructor from inside Java.
     */
    @io.qt.NativeAccess
    protected QSetFence(QDeclarativeConstructor constructor) {
        super((QPrivateConstructor)null);
        initialize_native(this, constructor);
    } 
    
    @io.qt.QtUninvokable
    private static native void initialize_native(QSetFence instance, QDeclarativeConstructor constructor);
    
}
